# Classification Head

::: linax.heads.classification.ClassificationHeadConfig
    options:
      members:
        - build

---

::: linax.heads.classification.ClassificationHead
    options:
      members:
        - __init__
        - __call__
